Alternative

Struct Alternative 

pub struct Alternative<T, Z: ?Sized>(pub T, pub PhantomData<Z>);
Wrapper to add an Alternative serialization to the inner type.

This will activate the Altered state when triggered by an outer Alt wrapper.

Tuple Fields

0: T1: PhantomData<Z>

Implementations

Source

impl<T, Z: ?Sized> Alternative<T, Z>

pub fn new(value: T) -> Self